@@ -34,7 +34,7 @@ import Options.Applicative.Types
 data OptionFields a = OptionFields
   { optNames :: [OptName]
   , optCompleter :: Completer
-  , optNoArgError :: ParseError }
+  , optNoArgError :: String -> ParseError }
 
 data FlagFields a = FlagFields
   { flagNames :: [OptName]
@@ -118,7 +118,7 @@ instance Semigroup (DefaultProp a) where
 --
 -- Modifiers are instances of 'Monoid', and can be composed as such.
 --
--- You rarely need to deal with modifiers directly, as most of the times it is
+-- One rarely needs to deal with modifiers directly, as most of the times it is
 -- sufficient to pass them to builders (such as 'strOption' or 'flag') to
 -- create options (see 'Options.Applicative.Builder').
 data Mod f a = Mod (f a -> f a)
@@ -135,6 +135,7 @@ instance Monoid (Mod f a) where
   mempty = Mod id mempty id
   mappend = (<>)
 
+-- | @since 0.13.0.0
 instance Semigroup (Mod f a) where
   Mod f1 d1 g1 <> Mod f2 d2 g2
     = Mod (f2 . f1) (d2 <> d1) (g2 . g1)
@@ -145,7 +146,9 @@ baseProps = OptProperties
   { propMetaVar = ""
   , propVisibility = Visible
   , propHelp = mempty
-  , propShowDefault = Nothing }
+  , propShowDefault = Nothing
+  , propDescMod = Nothing
+  }
 
 mkCommand :: Mod CommandFields a -> (Maybe String, [String], String -> Maybe (ParserInfo a))
 mkCommand m = (group, map fst cmds, (`lookup` cmds))
